/*********************************************************************
 *
 *                Microchip USB C18 Firmware Version 1.0
 *
 *********************************************************************
 * FileName:        main.c
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC18
 * Compiler:        C18 2.30.01+
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the CompanyE for its PICmicro Microcontroller is intended and
 * supplied to you, the Companys customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS ISECONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Rawin Rojvanit       11/19/04    Original.
 ********************************************************************/

/** I N C L U D E S **********************************************************/
#include <p18cxxx.h>
#include <timers.h>
#include <portb.h>
#include "system\typedefs.h"                        // Required
#include "system\usb\usb.h"                         // Required
#include "io_cfg.h"                                 // Required
#include "system\usb\usb_compile_time_validation.h" // Optional
#include "user\user.h"                        // Modifiable

/** D E F I N E S ************************************************************/

#define	stepX1	PORTDbits.RD0
#define	dirX1	PORTDbits.RD1

#define	stepX2	PORTDbits.RD3
#define	dirX2	PORTDbits.RD2

#define	stepY1	PORTDbits.RD5
#define	dirY1	PORTDbits.RD4

#define	stepY2	PORTDbits.RD7
#define	dirY2	PORTDbits.RD6

#define	ch_etat PORTAbits.RA0
#define	ch_val	PORTAbits.RA1
#define	ch_auto PORTAbits.RA2
#define	OE		PORTAbits.RA3

/** V A R I A B L E S ********************************************************/
#pragma udata

int		X1 = 0;		// Nombres de pas 16bits signs
int		X2 = 0;
int		Y1 = 0;
int		Y2 = 0;

unsigned	int	vX1 = 0;		// Vitesses 16bits non-signs
unsigned	int	vX2 = 0;
unsigned	int	vY1 = 0;
unsigned	int	vY2 = 0;

unsigned	int	c_vX1 = 0;		// Copie vitesses 16bits non-signs
unsigned	int	c_vX2 = 0;
unsigned	int	c_vY1 = 0;
unsigned	int	c_vY2 = 0;

unsigned char	c_stepX1 = 0;
unsigned char	c_stepX2 = 0;
unsigned char	c_stepY1 = 0;
unsigned char	c_stepY2 = 0;

unsigned char	chauffe = 0;
unsigned char	c_chauffe = 0;
unsigned char	rapport_chauffe = 0;
unsigned char	val_ch = 0;
unsigned char	c_val_ch = 0;

unsigned char	flag0 = 0;			// Drapeau de test fonction D
extern	flag1;


/** P R I V A T E  P R O T O T Y P E S ***************************************/
static void InitializeSystem(void);
void USBTasks(void);
void high_ISR(void); 
void low_isr(void); 
void my_hisr(void); 
void my_lisr(void); 
/** V E C T O R  R E M A P P I N G *******************************************/




extern void _startup (void);        // See c018i.c in your C18 compiler dir
#pragma code _RESET_INTERRUPT_VECTOR = 0x000800
void _reset (void)
{
    _asm goto _startup _endasm
}


#pragma code
#pragma interruptlow my_lisr
void my_lisr(void)
{
	int k;
    if (INTCONbits.INT0IF == 1)
    {
		if(rapport_chauffe == 100)
		{
			c_chauffe = chauffe;
			c_val_ch = val_ch;
			rapport_chauffe = 0;
			ch_auto = 1;
			val_ch = 0;
			flag1 = 1;
		}
		
		if(rapport_chauffe == c_chauffe)
		{
			ch_auto = 0;
		}
		rapport_chauffe = rapport_chauffe + 1;
		if (ch_val == 1) val_ch = val_ch + 1;

	    if(X1 != 0)
	    {
			c_stepX1 = 0;
		    c_vX1 = c_vX1 - 1;
		    if(c_vX1 == 0)
		    {
			    stepX1 = 1;
				//c_stepX1 = 1;
			    X1 = X1 - 1;
			 }
		}

		if(X2 != 0)
	    {
			c_stepX2 = 0;
		    c_vX2 = c_vX2 - 1;
		    if(c_vX2 == 0)
		    {
			    stepX2 = 1;
				//c_stepX2 = 1;
			    X2 = X2 - 1;
			 }
		}
		
		if(Y1 != 0)
	    {
			c_stepY1 = 0;
		    c_vY1 = c_vY1 - 1;
		    if(c_vY1 == 0)
		    {
			    stepY1 = 1;
				//c_stepY1 = 1;
			    Y1 = Y1 - 1;
			 }
		}
		
		if(Y2 != 0)
	    {
			c_stepY2 = 0;
		    c_vY2 = c_vY2 - 1;
		    if(c_vY2 == 0)
		    {
			    stepY2 = 1;
				//c_stepY2 = 1;
			    Y2 = Y2 - 1;
			 }
		}

/*		stepX1 = c_stepX1;
		stepX2 = c_stepX2;
		stepY1 = c_stepY1;
		stepY2 = c_stepY2;*/
		for (k = 0; k<0x15;k++) k=k;
		stepX1 = 0;
		stepX2 = 0;
		stepY1 = 0;
		stepY2 = 0;
		
		INTCONbits.INT0IF = 0;		// Reactive les interruptions
    }
}

#pragma code

#pragma interrupthigh my_hisr
void my_hisr(void)
{
   if (INTCONbits.INT0IF == 1)	// PIR1bits.TMR1IF == 1
    {
//		PORTBbits.RB7 ^= 1;
//		PIR1bits.TMR1IF = 0;
//		WriteTimer1(timervaleur);
		INTCONbits.INT0IF = 0;
    }
}

#pragma code _HIGH_INTERRUPT_VECTOR = 0x000808
void _high_ISR (void)
{
    _asm GOTO my_lisr _endasm
}

#pragma code _LOW_INTERRUPT_VECTOR = 0x000818
void _low_ISR (void)
{
    _asm GOTO my_hisr _endasm
}





/** D E C L A R A T I O N S **************************************************/
#pragma code
/******************************************************************************
 * Function:        void main(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        Main program entry point.
 *
 * Note:            None
 *****************************************************************************/
void main(void)
{
    InitializeSystem();
    while(1)
    {
        USBTasks();         // USB Tasks
        ProcessIO();        // See user\user.c & .h
    }//end while
}//end main

/******************************************************************************
 * Function:        static void InitializeSystem(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        InitializeSystem is a centralize initialization routine.
 *                  All required USB initialization routines are called from
 *                  here.
 *
 *                  User application initialization routine should also be
 *                  called from here.                  
 *
 * Note:            None
 *****************************************************************************/
static void InitializeSystem(void)
{
    ADCON1 |= 0x0F;                 // Default all pins to digital
    

    mInitializeUSBDriver();         // See usbdrv.h
    
    UserInit();                     // See user.c & .h
	
}//end InitializeSystem

/******************************************************************************
 * Function:        void USBTasks(void)
 *
 * PreCondition:    InitializeSystem has been called.
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        Service loop for USB tasks.
 *
 * Note:            None
 *****************************************************************************/
void USBTasks(void)
{
    /*
     * Servicing Hardware
     */
    USBCheckBusStatus();                    // Must use polling method
    if(UCFGbits.UTEYE!=1)
        USBDriverService();                 // Interrupt or polling method

}// end USBTasks

//configulation***************************************************************

/** EOF main.c ***************************************************************/
